@@ -21,6 +21,7 @@
 #include <atalk/dsi.h>
 #include <atalk/unicode.h>
 
+#include "afp_zeroconf.h"
 #include "afp_avahi.h"
 #include "afp_config.h"
 #include "volume.h"
@@ -71,7 +72,7 @@ static void register_stuff(void) {
 		
         for (volume = getvolumes(); volume; volume = volume->v_next) {
 
-            if (convert_string(CH_UCS2, CH_UTF8_MAC, volume->v_name, -1, tmpname, 255) <= 0) {
+            if (convert_string(CH_UCS2, CH_UTF8_MAC, volume->v_u8mname, -1, tmpname, 255) <= 0) {
                 LOG ( log_error, logtype_afpd, "Could not set Zeroconf volume name for TimeMachine");
                 goto fail;
             }
@@ -93,7 +94,9 @@ static void register_stuff(void) {
 
         /* AFP server */
         for (config = ctx->configs; config; config = config->next) {
-
+            if (config->obj.proto == AFPPROTO_ASP) {
+                continue;
+            }
             dsi = (DSI *)config->obj.handle;
             port = getip_port((struct sockaddr *)&dsi->server);
 
