@@ -1,6 +1,4 @@
 /*
- * $Id: ad_flush.c,v 1.14 2010-03-30 12:55:26 franklahm Exp $
- *
  * Copyright (c) 1990,1991 Regents of The University of Michigan.
  * All Rights Reserved.
  *
@@ -199,9 +197,9 @@ int ad_close( struct adouble *ad, int adflags)
     int         err = 0;
 
     if ((adflags & ADFLAGS_DF)
-        && ad_data_fileno(ad) >= 0
+        && (ad_data_fileno(ad) >= 0 || ad_data_fileno(ad) == -2) /* -2 means symlink */
         && --ad->ad_data_fork.adf_refcount == 0) {
-        if (ad->ad_data_fork.adf_syml !=0) {
+        if (ad->ad_data_fork.adf_syml != NULL) {
             free(ad->ad_data_fork.adf_syml);
             ad->ad_data_fork.adf_syml = 0;
         } else {
